==> v1.0.0.tar.gz: litexiv/tags/index.php <==
<?php
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
	header('Location: ' . $_POST['id']);
	die;
}

require_once '../include/utils.php';

$query = $_GET['id'];
$query_htmlescaped = htmlspecialchars($query);
$query_urlencoded = urlencode($query);

$current_page = (isset($_GET['p']) && ctype_digit($_GET['p']) && $_GET['p'] > 0) ? $_GET['p'] : 1;
$result = json_decode(
	get(sprintf(SEARCH_ARTWORKS_URL, $query_urlencoded, $current_page))
)->body->illustManga;
/* the endpoint always returns 60 per page*/
$page_count = ceil($result->total / 60);

if (!$result->data) {
	die_with_message(
		'¯\_(ツ)_/¯',
		'No works found or unexpected page number.'
	);
}

$tag_info = json_decode(
	get(sprintf(SEARCH_TAG_URL, $query_urlencoded))
)->body;

render_page_header($query_htmlescaped);
?>

<div class="container">
	<div class="tag-bar img-with-text">
		<?php if (isset($tag_info->pixpedia->image)) { ?>
			<img class="tag-icon" src="<?= get_proxy_url($tag_info->pixpedia->image) ?>">
		<?php } ?>
		<div>
			<?php
			$tag_jp = isset($tag_info->tag) ? htmlspecialchars($tag_info->tag) : $query_htmlescaped;
			if (isset($tag_info->tagTranslation->{$tag_info->tag})) {
				$tag_translations = $tag_info->tagTranslation->{$tag_info->tag};
				$tag_en = htmlspecialchars(
					isset($tag_translations->en) ? $tag_translations->en
					: (isset($tag_translations->romaji) ? $tag_translations->romaji : '')
				);
			}
			else $tag_en = '';
			?>
			<h1><?= $tag_jp ?></h1>
			<p><?= $tag_en ?></p>
		</div>
	</div>

	<?php if (isset($tag_info->pixpedia->abstract)) { ?>
		<p><?= htmlspecialchars($tag_info->pixpedia->abstract); ?></p>
	<?php } ?>

	<hr>

	<h2 id="artworks">Illustrations and Manga (<?= $result->total ?>)</h2>

	<?php
	render_artworks_grid($result->data, false);

	render_paginator($page_count, $current_page, function($page) use ($query_urlencoded) {
		return BASE_URL . '/tags/' . $query_urlencoded . '?p=' . $page . '#artworks';
	});
	?>
</div>

<?php
render_page_footer();

==> v1.1.0.tar.gz: litexiv/tags/index.php <==
<?php
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
	header('Location: ' . $_POST['id']);
	die;
}

require_once '../include/utils.php';
require_once '../include/artworks_grid.php';
require_once '../include/paginator.php';

$query = $_GET['id'];
$query_htmlescaped = htmlspecialchars($query);
$query_urlencoded = urlencode($query);

$current_page = (isset($_GET['p']) && ctype_digit($_GET['p']) && $_GET['p'] > 0) ? $_GET['p'] : 1;
$result = json_decode(
	get(sprintf(SEARCH_ARTWORKS_URL, $query_urlencoded, $current_page))
)->body->illustManga;
/* the endpoint always returns 60 per page*/
$page_count = ceil($result->total / 60);

if (!$result->data) {
	die_with_message(
		get_string('error'),
		get_string('tags.not-found')
	);
}

$tag_info = json_decode(
	get(sprintf(SEARCH_TAG_URL, $query_urlencoded))
)->body;

render_page_header($query_htmlescaped);
?>

<div class="container">
	<div class="tag-bar img-with-text">
		<?php if (isset($tag_info->pixpedia->image)) { ?>
			<img class="tag-icon" src="<?= get_proxy_url($tag_info->pixpedia->image) ?>">
		<?php } ?>
		<div>
			<?php
			$tag_jp = isset($tag_info->tag) ? htmlspecialchars($tag_info->tag) : $query_htmlescaped;
			if (isset($tag_info->tagTranslation->{$tag_info->tag})) {
				$tag_translations = $tag_info->tagTranslation->{$tag_info->tag};
				$tag_translated = htmlspecialchars(
					isset($tag_translations->{get_string('pixiv-lang')}) ? $tag_translations->{get_string('pixiv-lang')}
					: (isset($tag_translations->romaji) ? $tag_translations->romaji : '')
				);
			}
			else $tag_translated = '';
			?>
			<h1><?= $tag_jp ?></h1>
			<p><?= $tag_translated ?></p>
		</div>
	</div>

	<?php if (isset($tag_info->pixpedia->abstract)) { ?>
		<p><?= htmlspecialchars($tag_info->pixpedia->abstract); ?></p>
	<?php } ?>

	<hr>

	<h2 id="artworks"><?= sprintf(get_string('tags.work-count'), $result->total) ?></h2>

	<?php
	render_artworks_grid($result->data, false);

	render_paginator($page_count, $current_page, function($page) use ($query_urlencoded) {
		return BASE_URL . '/tags/' . $query_urlencoded . '?p=' . $page . '#artworks';
	});
	?>
</div>

<?php
render_page_footer();
